@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -454,7 +454,7 @@ static void setup_internal_mux(struct ofono_modem *modem)
 			ofono_error("Failed to create channel");
 			goto error;
 		}
-        }
+	}
 
 	/* wait for DLC creation to settle */
 	data->dlc_init_source = g_timeout_add(10, dlc_setup, modem);
@@ -574,7 +574,7 @@ static int ifx_enable(struct ofono_modem *modem)
 
 	data->device = g_at_tty_open(device, NULL);
 	if (data->device == NULL)
-                return -EIO;
+		return -EIO;
 
 	syntax = g_at_syntax_new_gsmv1();
 	chat = g_at_chat_new(data->device, syntax);
@@ -582,7 +582,7 @@ static int ifx_enable(struct ofono_modem *modem)
 
 	if (chat == NULL) {
 		g_io_channel_unref(data->device);
-                return -EIO;
+		return -EIO;
 	}
 
 	if (getenv("OFONO_AT_DEBUG"))
@@ -645,11 +645,10 @@ static void set_online_cb(gboolean ok, GAtResult *result, gpointer user_data)
 {
 	struct cb_data *cbd = user_data;
 	ofono_modem_online_cb_t cb = cbd->cb;
+	struct ofono_error error;
 
-	if (ok)
-		CALLBACK_WITH_SUCCESS(cb, cbd->data);
-	else
-		CALLBACK_WITH_FAILURE(cb, cbd->data);
+	decode_at_error(&error, g_at_result_final_response(result));
+	cb(&error, cbd->data);
 }
 
 static void ifx_set_online(struct ofono_modem *modem, ofono_bool_t online,
@@ -661,13 +660,13 @@ static void ifx_set_online(struct ofono_modem *modem, ofono_bool_t online,
 
 	DBG("%p %s", modem, online ? "online" : "offline");
 
-	if (g_at_chat_send(data->dlcs[AUX_DLC], command, NULL,
+	if (g_at_chat_send(data->dlcs[AUX_DLC], command, none_prefix,
 					set_online_cb, cbd, g_free) > 0)
 		return;
 
-	g_free(cbd);
-
 	CALLBACK_WITH_FAILURE(cb, cbd->data);
+
+	g_free(cbd);
 }
 
 static void ifx_pre_sim(struct ofono_modem *modem)
