@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2011  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License veasion 2 as
@@ -44,7 +44,7 @@ struct ofono_audio_settings {
 };
 
 void ofono_audio_settings_active_notify(struct ofono_audio_settings *as,
-                                                ofono_bool_t active)
+					ofono_bool_t active)
 {
 	const char *path = __ofono_atom_get_path(as->atom);
 	DBusConnection *conn = ofono_dbus_get_connection();
@@ -73,7 +73,7 @@ void ofono_audio_settings_mode_notify(struct ofono_audio_settings *as,
 	g_free(as->mode);
 	as->mode = g_strdup(mode);
 
-	if (!as->mode)
+	if (as->mode == NULL)
 		return;
 
 	ofono_dbus_signal_property_changed(conn, path,
@@ -89,7 +89,7 @@ static DBusMessage *audio_get_properties_reply(DBusMessage *msg,
 	DBusMessageIter dict;
 
 	reply = dbus_message_new_method_return(msg);
-	if (!reply)
+	if (reply == NULL)
 		return NULL;
 
 	dbus_message_iter_init_append(reply, &iter);
@@ -132,7 +132,7 @@ int ofono_audio_settings_driver_register(const struct ofono_audio_settings_drive
 {
 	DBG("driver: %p, name: %s", d, d->name);
 
-	if (!d || !d->probe)
+	if (d->probe == NULL)
 		return -EINVAL;
 
 	g_drivers = g_slist_prepend(g_drivers, (void *) d);
@@ -144,9 +144,6 @@ void ofono_audio_settings_driver_unregister(const struct ofono_audio_settings_dr
 {
 	DBG("driver: %p, name: %s", d, d->name);
 
-	if (!d)
-		return;
-
 	g_drivers = g_slist_remove(g_drivers, (void *) d);
 }
 
@@ -167,7 +164,7 @@ static void audio_settings_remove(struct ofono_atom *atom)
 
 	DBG("atom: %p", atom);
 
-	if (!as)
+	if (as == NULL)
 		return;
 
 	if (as->driver && as->driver->remove)
@@ -185,11 +182,11 @@ struct ofono_audio_settings *ofono_audio_settings_create(struct ofono_modem *mod
 	struct ofono_audio_settings *as;
 	GSList *l;
 
-	if (!driver)
+	if (driver == NULL)
 		return NULL;
 
 	as = g_try_new0(struct ofono_audio_settings, 1);
-	if (!as)
+	if (as == NULL)
 		return NULL;
 
 	as->atom = __ofono_modem_add_atom(modem, OFONO_ATOM_TYPE_AUDIO_SETTINGS,
